function [ub]=padnb(u,L)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function buffers up a given matrix with a buffer layer
% of thickness L. It uses homog neumann boundary conditions to fill
% the buffer layer.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Uses: upadnb.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Notes: If the input matrix u has size mxn, then the output 
%	 matrix ub has size (m+2*L)x(n+2*L).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[m,n]=size(u);

ub=zeros(m+2*L,n+2*L);	% Initialize ub.
ub(L+1:L+m,L+1:L+n)=u;	% Bulk part of ub is just u.

ub=upadnb(ub,L);	% Fills in buffer layer via neumann.

